==> dl.php?src=linea21_1_4.zip: linea21/languages/it/installer.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Simon Georget <simon@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$lang = array(

'direction' => 'ltr',
'charset' => 'UTF-8',

# Global
'G-01' => "Linea21 Install - version ". LINEA_VERSION. "", // @todo translation full file
'G-02' => "Steps (4)",
'G-03' => "Choose language (1/4)",
'G-04' => "Database Settings (2/4)",
'G-05' => "Configuration Settings (3/4)",
'G-06' => "Finish (4/4)",

# Errors
'L-01' => "The installer is locked! If you wish to continue with this installation please delete the installer.lock file",
'L-02' => "You must pass an array of options to the dbTables method",
'L-03' => "Please fill in all required fields.",
'L-04' => "Could not connect to the DB with those parameters",
'L-05' => "Could not select the right Database",
'L-06' => "Could not create the DB <b>%s</b> Error: %s",
'L-07' => "The database.php file was not found under %s",
'L-08' => "There was an error during a DB query. The error returned was: %s",
'L-09' => "DB Queries run. Total <b>%s</b> queries run. And a total of <b>%s</b> queries failed. %s",
'L-10' => "Configuration file written.",
'L-11' => "The template <b>%s</b> was not found under %s",

# Other
'I-01' => "Linea21 installation - Welcome",
'I-02' => "Choose the language you would like to view the installer with. <b>The installer is not translated into <i>Italian</i> but inputs will be written in <i>Italian</i> and the default software language will be set to <i>Italian</i>.</b>",
'I-03' => ">> Go!",
'I-04' => "Database Settings",
'I-05' => "Database Name",
'I-06' => "Database User",
'I-07' => "Database Pass",
'I-08' => "Database Host",
'I-09' => "Create Database if it doesn't exists?",
'I-10' => "Yes",
'I-11' => "No",
'I-12' => "Error!",
'I-13' => "Please <a href=\"javascript:history.go(-1)\">go back</a> and make sure the information provided is correct.",
'I-14' => "<h4>Those are the errors:</h4><br /> %s",
'I-15' => "Database creation",
'I-16' => "Continue Anyway...",
'I-17' => "Configuration File Settings",
'I-18' => "Base site url",
'I-19' => "Base site path",
'I-20' => "Finish",

'I-21' => "Installation Completed",
'I-22' => "The installation is completed.",
'I-23' => "-- Choose Language --",
'I-24' => "<a href=\"".SITE_LINEA_URL ."\">Linea21</a> installation - version ". LINEA_VERSION. "",

'l21-01' => "Database type",
'l21-02' => "Available for MySQL only! If you use PostgreSQL, the given database should already exists.",
'l21-03' => "Software inputs will be written with the selected language !",
'l21-04' => "Advanced settings options will be available after installation (from back-office).",
'l21-05' => "Do NOT change options below, except if you precisely know what you are doing.",
'l21-06' => "Site name (ex: <em>". SITE_NAME . "</em>)",
'l21-07' => "Email (ex: <em>". MAIL_FROM . "</em>)",
'l21-08' => "Associated name (ex: <em>". MAIL_FROMNAME . "</em>)",
'l21-09' => "Access to<a href=\"../admin/\">back-office</a>.",
'l21-10' => "Login/password : <strong>admin/linea</strong><br />Don't forget to change the default password!"
);

==> dl.php?src=linea21_1_7.zip: linea21/languages/it/installer.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Simon Georget <simon@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$lang = array(

'direction' => 'ltr',
'charset' => 'UTF-8',

# Global
'G-01' => "Linea21 Install - version ". LINEA_VERSION. "", // @todo translation full file
'G-02' => "Steps (4)",
'G-03' => "Choose language (1/4)",
'G-04' => "Database Settings (2/4)",
'G-05' => "Configuration Settings (3/4)",
'G-06' => "Finish (4/4)",

# Errors
'L-01' => "The installer is locked! If you wish to continue with this installation please delete the installer.lock file",
'L-02' => "You must pass an array of options to the dbTables method",
'L-03' => "Please fill in all required fields.",
'L-04' => "Could not connect to the DB with those parameters",
'L-05' => "Could not select the right Database",
'L-06' => "Could not create the DB <b>%s</b> Error: %s",
'L-07' => "The database.php file was not found under %s",
'L-08' => "There was an error during a DB query. The error returned was: %s",
'L-09' => "DB Queries run. Total <b>%s</b> queries run. And a total of <b>%s</b> queries failed. %s",
'L-10' => "Configuration file written.",
'L-11' => "The template <b>%s</b> was not found under %s",
'L-12' => "Configuration files are not writable. <br />Please change permissions on  <code>./config/</code> folder.",
'L-13' => "Installation folder is not writable. <br />Please change permissions on  <code>./install/</code> folder.",

# Other
'I-01' => "Linea21 installation - Welcome",
'I-02' => "Choose the language you would like to view the installer with. <b>The installer is not translated into <i>Italian</i> but inputs will be written in <i>Italian</i> and the default software language will be set to <i>Italian</i>.</b>",
'I-03' => ">> Go!",
'I-04' => "Database Settings",
'I-05' => "Database Name",
'I-06' => "Database User",
'I-07' => "Database Pass",
'I-08' => "Database Host",
'I-09' => "Create Database if it doesn't exists?",
'I-10' => "Yes",
'I-11' => "No",
'I-12' => "Error!",
'I-13' => "Please <a href=\"javascript:history.go(-1)\">go back</a> and make sure the information provided is correct.",
'I-14' => "<h4>Those are the errors:</h4><br /> %s",
'I-15' => "Database creation",
'I-16' => "Continue Anyway...",
'I-17' => "Configuration File Settings",
'I-18' => "Base site url",
'I-19' => "Base site path",
'I-20' => "Finish",

'I-21' => "Installation Completed",
'I-22' => "The installation is completed. For security reason, please remove installation folder (<code>/install/</code>).",
'I-23' => "-- Choose Language --",
'I-24' => "<a href=\"".SITE_LINEA_URL ."\">Linea21</a> installation - version ". LINEA_VERSION. "",

'l21-01' => "Database type",
'l21-02' => "Available for MySQL only! If you use PostgreSQL, the given database should already exists.",
'l21-03' => "Software inputs will be written with the selected language !",
'l21-04' => "Advanced settings options will be available after installation (from back-office).",
'l21-05' => "Do NOT change options below, except if you precisely know what you are doing.",
'l21-06' => "Site name (ex: <em>". SITE_NAME . "</em>)",
'l21-07' => "Email (ex: <em>". MAIL_FROM . "</em>)",
'l21-08' => "Associated name (ex: <em>". MAIL_FROMNAME . "</em>)",
'l21-09' => "Access to<a href=\"../admin/\">back-office</a>.",
'l21-10' => "Login/password : <strong>admin/linea</strong><br />Don't forget to change the default password!",
'l21-11' => "Use of PostgreSQL databse is deprecated. It will not be implemented anymore in next releases."
);
